Description Usage Arguments Details Value Author(s) Examples
View source: R/empirical.GoF.R
Fit models 1 and 2 to data and return the empirical goodnesses of fit as well as the difference in goodness of fit.
1 2 3 4 5 6 7 8 9 | empirical.GoF(
data,
fun1,
fun2,
args1 = NULL,
args2 = NULL,
verbose = TRUE,
GoFname = "GoF"
)
|
data |
Data frame |
fun1 |
Modelling function 1 |
fun2 |
Modelling function 2 |
args1 |
List of arguments passed to |
args2 |
List of arguments passed to |
verbose |
If |
GoFname |
Name of the element returned by |
Functions fun1 and fun2 must accept data as an argument in addition to any arguments specified in args1 and args2. They must return a list with an element carrying the calculated goodness of fit; by default the name of this element is taken to be the string "GoF" but this behaviour can be changed through the GoFname argument.
A 1-row data frame of three columns:
GoF1Goodness of fit for model 1
GoF2Goodness of fit for model 2
DeltaGoFEqual to GoF1 - GoF2
Henri Kauhanen
1 2 3 4 5 6 7 8 9 10 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.